Port of Composer\DependencyResolver\PoolOptimizer: removes from the
pool the versions whose dependencies are identical to a preferred
version, and those a locked package makes impossible.
Port of Composer\DependencyResolver\PoolOptimizer: removes from the
pool the versions whose dependencies are identical to a preferred
version, and those a locked package makes impossible.