pub struct FilterError(pub String, pub RepoErrorKind);Tuple Fields
0: String1: RepoErrorKindTrait Implementations
Sourceimpl Debug for FilterError
impl Debug for FilterError
Sourceimpl Display for FilterError
impl Display for FilterError
Sourceimpl Error for FilterError
impl Error for FilterError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<FilterError> for SessionError
A filter error, on the other hand, can be either.
impl From<FilterError> for SessionError
A filter error, on the other hand, can be either.
Sourcefn from(e: FilterError) -> SessionError
fn from(e: FilterError) -> SessionError
Converts to this type from the input type.
Sourceimpl From<RepoError> for FilterError
The nature travels, as it does out of the pool: a list that could not be
fetched is not a list that could not be read.
impl From<RepoError> for FilterError
The nature travels, as it does out of the pool: a list that could not be fetched is not a list that could not be read.
Sourcefn from(e: RepoError) -> FilterError
fn from(e: RepoError) -> FilterError
Converts to this type from the input type.