Port of Composer\Semver\Constraint\* and VersionParser::parseConstraints
(docs/reference/resolver/semver-Constraint.php, semver-MultiConstraint.php,
semver-Bound.php, semver-VersionParser.php). A constraint is a tree: leaf
(operator, normalized version), conjunction/disjunction, match-all,
match-none. matches reproduces Constraint::matchSpecific (and thus
CompilingMatcher::match, which is merely a compiled form of it).
Structs
- Bound
Bound.- Parsed
Constraint - A parsed constraint with its original pretty string (
getPrettyString).
Enums
Functions
- parse_
constraints VersionParser::parseConstraints, memoized by text (the equivalent of the$linkCacheofArrayLoader::loadPackages, at process scope: same input -> same result, the parser is pure).